Skip to contents

Creates an empty item (file) in the node's binary cache and returns its unique identifier. Binary cache items are temporary storage for binary data that can be used in transactions or passed between nodes.

Usage

mc_create_binary_cache(conn)

Arguments

conn

A connection object created by mc_connect.

Value

A character string identifier (filename) for the newly created cache item.

Examples

if (FALSE) { # \dontrun{
id <- mc_create_binary_cache(conn)
} # }