Skip to contents

Creates a global variable, specifying the address that issues the transaction.

Usage

mc_create_variable_from(conn, from_address, name, open = TRUE, value = NULL)

Arguments

conn

A connection object created by mc_connect.

from_address

Character string. Address that pays for and creates the variable.

name

Character string. Variable name.

open

Logical. If TRUE, anyone with create permissions can edit the variable.

value

Optional. Initial JSON value.

Value

A list containing the result of the RPC call (usually transaction ID).

Examples

if (FALSE) { # \dontrun{
mc_create_variable_from(conn, "1A...", "myvar", open = TRUE, value = 42)
} # }