Skip to contents

Invalidates a previously created partial exchange transaction, preventing it from being completed. The transaction is replaced with a disabling transaction that spends the locked output(s) back to the original owner(s).

Usage

mc_disable_raw_transaction(conn, tx_hex)

Arguments

conn

A connection object created by mc_connect.

tx_hex

Character string. Hexadecimal representation of the exchange transaction to disable.

Value

Character string. Transaction ID of the disabling transaction.

Examples

if (FALSE) { # \dontrun{
# After creating an offer, but before completion, you may decide to cancel
disable_txid <- mc_disable_raw_transaction(conn, offer_hex)
} # }