Skip to contents

Encrypts the wallet with a passphrase for the first time.

Usage

mc_encrypt_wallet(conn, passphrase)

Arguments

conn

A connection object to the MultiChain node.

passphrase

Character. The new wallet password.

Value

Invisibly returns the RPC result (a message indicating the node is shutting down).

Warning

MultiChain will shut down after this command is successful. You must manually restart the node to continue operations.