Skip to contents

Provides information about a specific transaction, but only if it involves the specified address.

Usage

mc_get_address_transaction(conn, address, txid, verbose = FALSE)

Arguments

conn

A connection object to the MultiChain node.

address

Character. The MultiChain address to query.

txid

Character. The transaction ID.

verbose

Logical. If TRUE, provides a detailed breakdown of inputs and outputs (default FALSE).

Value

A list containing transaction details.