Returns the total number of various objects in the blockchain, such as addresses, transactions, assets, streams, and permissions.
Arguments
- conn
A connection object created by
mc_connect.
Value
A list with counts, typically containing:
- addresses
Number of addresses.
- transactions
Number of transactions.
- assets
Number of assets.
- streams
Number of streams.
- permissions
Number of permission entries.
See also
mc_get_blockchain_info for global blockchain stats.
Other blockchain information:
mc_get_block(),
mc_get_block_hash(),
mc_get_blockchain_info(),
mc_get_last_block_info(),
mc_list_blocks(),
mc_list_miners()
Examples
if (FALSE) { # \dontrun{
totals <- mc_get_chain_totals(conn)
print(totals$transactions)
} # }