Skip to contents

Retrieves details of the most recent block, optionally skipping back by a number of blocks.

Usage

mc_get_last_block_info(conn, skip = 0)

Arguments

conn

A connection object created by mc_connect.

skip

Integer. Number of blocks to skip back from the tip. skip = 0 returns the latest block, skip = 1 returns the previous block, etc. Default is 0.

Value

A list with block information (similar to mc_get_block).

Examples

if (FALSE) { # \dontrun{
latest <- mc_get_last_block_info(conn)
previous <- mc_get_last_block_info(conn, skip = 1)
} # }