Skip to contents

This function is used to retrieve large data payloads (like stream data) that may have been truncated in standard transaction calls.

Usage

mc_get_tx_out_data(conn, txid, vout, count_bytes = NULL, start_byte = 0)

Arguments

conn

A connection object to the MultiChain node.

txid

Character. The transaction ID containing the output.

vout

Integer. The index of the output (starting from 0).

count_bytes

Integer. The number of bytes to retrieve. If NULL, returns all data.

start_byte

Integer. The byte offset to start reading from (default 0).

Value

A list or string containing the hex data from the transaction output.