Skip to contents

Grants one or more permissions to a wallet address. Permissions control what actions an address can perform on the blockchain (e.g., connect, send, receive, mine, admin, etc.).

Usage

mc_grant(conn, address, permissions)

Arguments

conn

A connection object created by mc_connect.

address

Character string. The address that will receive the permissions.

permissions

Character string. A comma‑separated list of permissions to grant, e.g., "connect,send,receive".

Value

A character string containing the transaction ID (txid) of the grant.

Examples

if (FALSE) { # \dontrun{
# Grant connect and send permissions to an address
txid <- mc_grant(conn, "1A...", "connect,send")
} # }