Skip to contents

Adds private keys to the node's wallet.

Usage

mc_import_privkey(conn, privkeys, label = "", rescan = TRUE)

Arguments

conn

A connection object to the MultiChain node.

privkeys

A character string or vector of private keys (WIF format).

label

Optional character string. A label to assign to the addresses.

rescan

Logical or Integer. If TRUE, rescans the entire blockchain. Can also be an integer representing the block height to start scanning from.

Value

Returns NULL on success.