Skip to contents

Increases the supply of a previously issued fungible asset. The asset must be open for further issuances (i.e., its open property must be TRUE).

Usage

mc_issue_more(
  conn,
  address,
  asset,
  quantity,
  native_amount = NULL,
  custom_fields = NULL
)

Arguments

conn

A connection object created by mc_connect.

address

Character string. Address that will receive the newly issued units.

asset

Character string. Asset name, reference, or issuance transaction ID.

quantity

Numeric. Additional quantity to issue.

native_amount

Numeric (optional). Amount of native currency to send.

custom_fields

List (optional). Custom fields (overwrites existing ones if present).

Value

A character string containing the transaction ID.

Examples

if (FALSE) { # \dontrun{
# Increase supply of "mycoin" by 500 units
txid <- mc_issue_more(conn, "1A...", "mycoin", quantity = 500)
} # }