Skip to contents

Increases the supply of a fungible asset, specifying the address that pays for and initiates the transaction.

Usage

mc_issue_more_from(
  conn,
  from_address,
  to_address,
  asset,
  quantity,
  native_amount = NULL,
  custom_fields = NULL
)

Arguments

conn

A connection object created by mc_connect.

from_address

Character string. Address that will pay for and issue the additional units.

to_address

Character string. Recipient address.

asset

Character string. Asset name, reference, or issuance transaction ID.

quantity

Numeric. Additional quantity to issue.

native_amount

Numeric (optional). Amount of native currency to send.

custom_fields

List (optional). Custom fields (overwrites existing ones if present).

Value

A character string containing the transaction ID.

Examples

if (FALSE) { # \dontrun{
# Issue more from a specific address to another address
txid <- mc_issue_more_from(conn, "1A...", "1B...", "mycoin", quantity = 100)
} # }