Skip to contents

Returns a list of the most recent transactions involving the specified address.

Usage

mc_list_address_transactions(
  conn,
  address,
  count = 10,
  skip = 0,
  verbose = FALSE
)

Arguments

conn

A connection object to the MultiChain node.

address

Character. The MultiChain address to query.

count

Integer. The number of transactions to return (default 10).

skip

Integer. The number of transactions to skip (default 0).

verbose

Logical. If TRUE, provides details of inputs and outputs (default FALSE).

Value

A data frame of transaction history for the address.