Skip to contents

Returns a list of unspent transaction outputs that have been temporarily locked by mc_lock_unspent.

Usage

mc_list_lock_unspent(conn)

Arguments

conn

A connection object to the MultiChain node.

Value

A data frame containing columns for txid and vout.