Skip to contents

Returns a list of nodes that the node has stored in its address manager. This includes peers that were connected to or manually added.

Usage

mc_list_stored_nodes(conn, include_old_ignores = FALSE)

Arguments

conn

A connection object created by mc_connect.

include_old_ignores

Logical. If TRUE, includes nodes that were previously ignored. Default is FALSE.

Value

A data frame (via rpc_res_to_df) of stored nodes.

Examples

if (FALSE) { # \dontrun{
nodes <- mc_list_stored_nodes(conn)
} # }