Skip to contents

Returns stream items that were published in one or more blocks.

Usage

mc_list_stream_block_items(
  conn,
  stream,
  blocks,
  verbose = FALSE,
  count = NULL,
  start = NULL
)

Arguments

conn

A connection object created by mc_connect.

stream

Character string. Stream name, reference, or txid.

blocks

A vector of block heights, block hashes, or timestamps.

verbose

Logical. If TRUE, returns detailed information.

count

Optional integer. Number of items to return.

start

Optional integer. Offset.

Value

A data frame (via rpc_res_to_df) with items.

Examples

if (FALSE) { # \dontrun{
# Items in block height 100
items <- mc_list_stream_block_items(conn, "mystream", 100)

# Items in multiple blocks
items <- mc_list_stream_block_items(conn, "mystream", c(100, 101, 102))
} # }