Skip to contents

Returns all stream items that are part of a specific transaction (e.g., when multiple items were published in a single transaction).

Usage

mc_list_stream_tx_items(conn, stream, txid, verbose = FALSE)

Arguments

conn

A connection object created by mc_connect.

stream

Character string. Stream name, reference, or txid.

txid

Character string. Transaction ID.

verbose

Logical. If TRUE, returns detailed information.

Value

A data frame (via rpc_res_to_df) with items.

Examples

if (FALSE) { # \dontrun{
items <- mc_list_stream_tx_items(conn, "mystream", "txid...")
} # }