Skip to contents

Returns a list of the most recent transactions in the wallet.

Usage

mc_list_wallet_transactions(
  conn,
  count = 10,
  skip = 0,
  include_watch_only = FALSE,
  verbose = FALSE
)

Arguments

conn

A connection object to the MultiChain node.

count

Integer. The number of transactions to return (default 10).

skip

Integer. The number of transactions to skip (default 0).

include_watch_only

Logical. Include watch-only addresses (default FALSE).

verbose

Logical. If TRUE, provides details of inputs and outputs (default FALSE).

Value

A data frame of transaction history for the wallet.