Skip to contents

Creates a new blockchain using the multichain-util command. The new blockchain is set up in the MultiChain data directory (platform‑specific).

Usage

mc_node_init(chain_name)

Arguments

chain_name

Character string. Name of the blockchain to create.

Value

Invisibly returns the output of the multichain-util create command (a character vector). If the creation fails, the function stops with an error.

See also

mc_node_start to start the created node, mc_node_stop to stop it.

Other node operations: mc_node_start(), mc_node_stop()

Examples

if (FALSE) { # \dontrun{
# Create a blockchain called "my_chain"
mc_node_init("my_chain")
} # }