Skip to contents

Revokes permissions from an address, specifying the address that issues the revocation. This allows controlling which address pays for the transaction.

Usage

mc_revoke_from(conn, from_address, to_address, permissions, native_amount = 0)

Arguments

conn

A connection object created by mc_connect.

from_address

Character string. The address revoking the permissions.

to_address

Character string. The address losing the permissions.

permissions

Character string. Comma‑separated list of permissions to revoke.

native_amount

Numeric. Amount of native currency to send along with the revocation (default 0).

Value

A character string containing the transaction ID.

Examples

if (FALSE) { # \dontrun{
# Revoke from a specific admin address
txid <- mc_revoke_from(conn, "admin1...", "user1...", "send")
} # }