Skip to contents

Executes an existing stream filter on a specific stream item (transaction and optional vout).

Usage

mc_run_stream_filter(conn, filter, tx, vout = NULL)

Arguments

conn

A connection object created by mc_connect.

filter

Character string. Filter name or transaction ID.

tx

Character string. Transaction ID or hex representation.

vout

Optional integer. Output index if the stream item is in a transaction output.

Value

The output of the filter.

Examples

if (FALSE) { # \dontrun{
result <- mc_run_stream_filter(conn, "myfilter", "txid...", vout = 0)
} # }