Skip to contents

Stores a node address in the node's address manager. This can be used to manually add a peer for future connections or to ignore a node.

Usage

mc_store_node(conn, node, command = c("tryconnect", "ignore"))

Arguments

conn

A connection object created by mc_connect.

node

Character string. The IP address and port of the peer node.

command

Character string. Action to perform:

  • "tryconnect" – store the node and try to connect to it (default).

  • "ignore" – ignore the node (do not attempt connections).

Value

Invisibly returns the RPC result (typically NULL) on success.

Examples

if (FALSE) { # \dontrun{
# Add a node to the address manager
mc_store_node(conn, "192.168.1.20:8571", command = "tryconnect")
} # }