Converts a hexadecimal encoded string back into its original character representation. This is primarily used for reading human-readable data published to MultiChain streams.
Value
A decoded character string. If the input is not a valid hex string
or an error occurs during decoding, the original hex_str is returned.