Appends data to an existing binary cache item. If data = ""
(the default), the RPC call returns the current size without adding new data.
Arguments
- conn
A connection object created by
mc_connect.- identifier
Character string. The cache item identifier returned by
mc_create_binary_cache.- data
Data to append. Can be:
a character string of hex data,
a list with element
text(will be converted to hex),a list with element
json(will be converted to JSON and then to hex),""(default) returns the current size without appending.
Value
Integer. The resulting size of the cache item in bytes after appending
(or the current size if data = "").
See also
Other binary cache:
mc_create_binary_cache(),
mc_delete_binary_cache(),
mc_txout_to_binary_cache()