Removes all unconfirmed transactions from the node's memory pool (mempool).
This function is typically used after pausing incoming and mining tasks to
reset the mempool state. It requires the node to be paused first with
mc_pause(conn, "incoming,mining").
Arguments
- conn
A connection object created by
mc_connect.
See also
mc_pause, mc_resume,
mc_get_mempool_info to inspect mempool state.