Skip to contents

Sends transactions to combine many small unspent transaction outputs (UTXOs) into a single output. This is used to improve wallet performance and reduce the size of the wallet's UTXO set.

Usage

mc_combine_unspent(
  conn,
  addresses = "*",
  minconf = 1,
  maxcombines = 100,
  mininputs = 2,
  maxinputs = 100,
  maxtime = 15
)

Arguments

conn

A connection object to the MultiChain node.

addresses

A vector of addresses, or "*" for all addresses (default "*").

minconf

Integer. Minimum confirmations (default 1).

maxcombines

Integer. Maximum number of transactions to create (default 100).

mininputs

Integer. Minimum number of inputs per transaction (default 2).

maxinputs

Integer. Maximum number of inputs per transaction (default 100).

maxtime

Integer. Maximum seconds to spend combining (default 15).

Value

A character vector of the transaction IDs (txids) created.