Creates an empty item (file) in the node's binary cache and returns its unique identifier. Binary cache items are temporary storage for binary data that can be used in transactions or passed between nodes.
Arguments
- conn
A connection object created by
mc_connect.
See also
mc_append_binary_cache to add data,
mc_delete_binary_cache to remove.
Other binary cache:
mc_append_binary_cache(),
mc_delete_binary_cache(),
mc_txout_to_binary_cache()