Creates a new stream on the blockchain. Streams are ordered collections of key‑value items that can be used for data storage, messaging, or other applications. The stream can be open (anyone can write) or restricted.
Arguments
- conn
A connection object created by
mc_connect.- name
Character string. Name of the stream (must be unique).
- open
Either a logical (TRUE for open stream, FALSE for restricted) or a list of parameters, e.g.,
list(restrict = "write"). For open streams, any address withsendpermission can publish. For restricted, only addresses withwritepermission on the stream can publish.- custom_fields
Optional list of custom fields (e.g.,
list(field1 = "value")).
See also
mc_create_stream_from to specify the creator address,
mc_get_stream_info to query stream details.
Other streams:
mc_create_stream_from(),
mc_get_stream_info(),
mc_get_stream_item(),
mc_get_stream_key_summary(),
mc_get_stream_publisher_summary(),
mc_list_stream_block_items(),
mc_list_stream_items(),
mc_list_stream_key_items(),
mc_list_stream_keys(),
mc_list_stream_publisher_items(),
mc_list_stream_publishers(),
mc_list_stream_query_items(),
mc_list_stream_tx_items(),
mc_list_streams(),
mc_publish(),
mc_publish_from(),
mc_publish_multi(),
mc_publish_multi_from()