Invalidates a previously created partial exchange transaction, preventing it from being completed. The transaction is replaced with a disabling transaction that spends the locked output(s) back to the original owner(s).
Arguments
- conn
A connection object created by
mc_connect.- tx_hex
Character string. Hexadecimal representation of the exchange transaction to disable.