Encrypts the wallet with a passphrase for the first time.
Usage
mc_encrypt_wallet(conn, passphrase)
Arguments
- conn
A connection object to the MultiChain node.
- passphrase
Character. The new wallet password.
Value
Invisibly returns the RPC result (a message indicating the node
is shutting down).
Warning
MultiChain will shut down after this command is successful. You must
manually restart the node to continue operations.
See also
Other wallet:
mc_backup_wallet(),
mc_change_wallet_passphrase(),
mc_combine_unspent(),
mc_dump_privkey(),
mc_dump_wallet(),
mc_get_wallet_info(),
mc_import_privkey(),
mc_import_wallet(),
mc_list_lock_unspent(),
mc_list_unspent(),
mc_lock_unspent(),
mc_lock_wallet(),
mc_unlock_wallet()