Retrieves details of the most recent block, optionally skipping back by a number of blocks.
Arguments
- conn
A connection object created by
mc_connect.- skip
Integer. Number of blocks to skip back from the tip.
skip = 0returns the latest block,skip = 1returns the previous block, etc. Default is0.
Value
A list with block information (similar to mc_get_block).
See also
mc_get_block for general block retrieval.
Other blockchain information:
mc_get_block(),
mc_get_block_hash(),
mc_get_blockchain_info(),
mc_get_chain_totals(),
mc_list_blocks(),
mc_list_miners()