This function is used to retrieve large data payloads (like stream data) that may have been truncated in standard transaction calls.
Arguments
- conn
A connection object to the MultiChain node.
- txid
Character. The transaction ID containing the output.
- vout
Integer. The index of the output (starting from 0).
- count_bytes
Integer. The number of bytes to retrieve. If
NULL, returns all data.- start_byte
Integer. The byte offset to start reading from (default
0).
See also
Other transactions:
mc_get_address_balances(),
mc_get_address_transaction(),
mc_get_multi_balances(),
mc_get_token_balances(),
mc_get_total_balances(),
mc_get_wallet_transaction(),
mc_list_address_transactions(),
mc_list_wallet_transactions(),
mc_send(),
mc_send_asset(),
mc_send_asset_from(),
mc_send_from(),
mc_send_with_data(),
mc_send_with_data_from()