Grants one or more permissions to a wallet address. Permissions control what actions an address can perform on the blockchain (e.g., connect, send, receive, mine, admin, etc.).
Arguments
- conn
A connection object created by
mc_connect.- address
Character string. The address that will receive the permissions.
- permissions
Character string. A comma‑separated list of permissions to grant, e.g.,
"connect,send,receive".
See also
mc_grant_from to specify the grantor,
mc_revoke to revoke permissions,
mc_list_permissions to view permissions.
Other permissions:
mc_grant_from(),
mc_grant_with_data(),
mc_grant_with_data_from(),
mc_list_permissions(),
mc_revoke(),
mc_revoke_from(),
mc_verify_permission()