Adds an address (without a private key) to the node's wallet for monitoring. The node will be able to see transactions involving this address, but cannot spend funds from it.
Arguments
- conn
A connection object created by
mc_connect.- address
Character string. The wallet address to import.
- label
Character string (optional). A label to assign to the address. Default is
""(no label).- rescan
Logical. If
TRUE(default), the node will scan the blockchain for transactions associated with this address.
Value
Invisibly returns the RPC result (typically NULL) on success;
throws an error if the import fails.
See also
mc_validate_address to check address validity.
Other addresses:
mc_add_multisig_address(),
mc_create_keypairs(),
mc_create_multisig(),
mc_get_addresses(),
mc_get_new_address(),
mc_list_addresses(),
mc_validate_address()