Adds private keys to the node's wallet.
Usage
mc_import_privkey(conn, privkeys, label = "", rescan = TRUE)
Arguments
- conn
A connection object to the MultiChain node.
- privkeys
A character string or vector of private keys (WIF format).
- label
Optional character string. A label to assign to the addresses.
- rescan
Logical or Integer. If TRUE, rescans the entire blockchain.
Can also be an integer representing the block height to start scanning from.
Value
Returns NULL on success.
See also
Other wallet:
mc_backup_wallet(),
mc_change_wallet_passphrase(),
mc_combine_unspent(),
mc_dump_privkey(),
mc_dump_wallet(),
mc_encrypt_wallet(),
mc_get_wallet_info(),
mc_import_wallet(),
mc_list_lock_unspent(),
mc_list_unspent(),
mc_lock_unspent(),
mc_lock_wallet(),
mc_unlock_wallet()