Issues a new asset, but allows specifying the sender address (which must have sufficient native currency to pay for the transaction). This is useful when the node has multiple addresses.
Usage
mc_issue_from(
conn,
from_address,
to_address,
name,
quantity,
units = 1,
native_amount = NULL,
custom_fields = NULL
)Arguments
- conn
A connection object created by
mc_connect.- from_address
Character string. Address that will pay for and issue the asset.
- to_address
Character string. Recipient address (can be the same as
from_address).- name
Either a character string (asset name) or a list of asset parameters (e.g.,
list(name = "myasset", open = TRUE)).- quantity
Numeric. Total amount to issue.
- units
Numeric. Smallest divisible unit. Default is
1.- native_amount
Numeric (optional). Amount of native currency to send along with the issuance.
- custom_fields
List (optional). Custom fields.
See also
mc_issue for simpler issuance,
mc_issue_more_from to increase supply.
Other assets:
mc_get_asset_info(),
mc_get_token_info(),
mc_issue(),
mc_issue_more(),
mc_issue_more_from(),
mc_issue_token(),
mc_issue_token_from(),
mc_list_asset_issues(),
mc_list_assets(),
mc_update(),
mc_update_from()