Increases the supply of a fungible asset, specifying the address that pays for and initiates the transaction.
Usage
mc_issue_more_from(
conn,
from_address,
to_address,
asset,
quantity,
native_amount = NULL,
custom_fields = NULL
)Arguments
- conn
A connection object created by
mc_connect.- from_address
Character string. Address that will pay for and issue the additional units.
- to_address
Character string. Recipient address.
- asset
Character string. Asset name, reference, or issuance transaction ID.
- quantity
Numeric. Additional quantity to issue.
- native_amount
Numeric (optional). Amount of native currency to send.
- custom_fields
List (optional). Custom fields (overwrites existing ones if present).
See also
mc_issue_more for simpler usage,
mc_issue_from for initial issuance.
Other assets:
mc_get_asset_info(),
mc_get_token_info(),
mc_issue(),
mc_issue_from(),
mc_issue_more(),
mc_issue_token(),
mc_issue_token_from(),
mc_list_asset_issues(),
mc_list_assets(),
mc_update(),
mc_update_from()