Returns a list of unspent transaction outputs that have been temporarily
locked by mc_lock_unspent.
Usage
mc_list_lock_unspent(conn)
Arguments
- conn
A connection object to the MultiChain node.
Value
A data frame containing columns for txid and vout.
See also
Other wallet:
mc_backup_wallet(),
mc_change_wallet_passphrase(),
mc_combine_unspent(),
mc_dump_privkey(),
mc_dump_wallet(),
mc_encrypt_wallet(),
mc_get_wallet_info(),
mc_import_privkey(),
mc_import_wallet(),
mc_list_unspent(),
mc_lock_unspent(),
mc_lock_wallet(),
mc_unlock_wallet()