Returns a list of nodes that the node has stored in its address manager. This includes peers that were connected to or manually added.
Arguments
- conn
A connection object created by
mc_connect.- include_old_ignores
Logical. If
TRUE, includes nodes that were previously ignored. Default isFALSE.
See also
mc_store_node to add a node to the stored list.
Other networking:
mc_add_node(),
mc_get_added_node_info(),
mc_get_network_info(),
mc_get_peer_info(),
mc_ping(),
mc_store_node()