Prepare an unspent output from a specific address
Source:R/atomic_exchange.R
mc_prepare_lock_unspent_from.RdSimilar to mc_prepare_lock_unspent, but allows specifying
the source address from which to lock the outputs. This is useful when
the node has multiple addresses and you want to control which address's
funds are used.
Arguments
- conn
A connection object created by
mc_connect.- from_address
Character string. The address that will provide the assets/native currency.
- amounts
A list specifying the assets or native currency to lock.
- lock
Logical. If
TRUE(default), the output is locked for automatic spending.
Examples
if (FALSE) { # \dontrun{
locked <- mc_prepare_lock_unspent_from(conn, "1A...",
amounts = list(myasset = 5))
} # }