Revokes permissions from an address, specifying the address that issues the revocation. This allows controlling which address pays for the transaction.
Arguments
- conn
A connection object created by
mc_connect.- from_address
Character string. The address revoking the permissions.
- to_address
Character string. The address losing the permissions.
- permissions
Character string. Comma‑separated list of permissions to revoke.
- native_amount
Numeric. Amount of native currency to send along with the revocation (default 0).