Executes an existing stream filter on a specific stream item (transaction and optional vout).
Arguments
- conn
A connection object created by
mc_connect.- filter
Character string. Filter name or transaction ID.
- tx
Character string. Transaction ID or hex representation.
- vout
Optional integer. Output index if the stream item is in a transaction output.
See also
mc_test_stream_filter, mc_create_stream_filter
Other filters:
mc_approve_from(),
mc_create_stream_filter(),
mc_create_tx_filter(),
mc_create_upgrade(),
mc_get_filter_code(),
mc_list_stream_filters(),
mc_list_tx_filters(),
mc_list_upgrades(),
mc_run_tx_filter(),
mc_test_stream_filter(),
mc_test_tx_filter()