Stores a node address in the node's address manager. This can be used to manually add a peer for future connections or to ignore a node.
Usage
mc_store_node(conn, node, command = c("tryconnect", "ignore"))Arguments
- conn
A connection object created by
mc_connect.- node
Character string. The IP address and port of the peer node.
- command
Character string. Action to perform:
"tryconnect"– store the node and try to connect to it (default)."ignore"– ignore the node (do not attempt connections).
See also
mc_list_stored_nodes to list stored nodes.
Other networking:
mc_add_node(),
mc_get_added_node_info(),
mc_get_network_info(),
mc_get_peer_info(),
mc_list_stored_nodes(),
mc_ping()