Instructs the MultiChain node to stop tracking one or more asset(s) or stream(s).
Arguments
- conn
A connection object to the MultiChain node.
- entities
A character string or vector of strings representing asset/stream names, references, or transaction IDs (txids).
- purge
Logical. If
TRUE, any off-chain data retrieved for this stream will be permanently purged from the node's local storage. Defaults toFALSE.
See also
Other subscriptions:
mc_subscribe()